// challenge-bot
// GNU AGPLv3 (or later at your option)
// project available at these locations:
// https://gitorious.org/ozzloy/challenge-bot
// https://github.com/waynegramlich/challenge-bot

include <caster-standoff-dimensions.scad>
use <oshw.scad>

// use 10 ish for development, 60 or so for printing
$fn = 60;

module deck_flange(){
  deck_pitch_diagonal = sqrt(2 * pow(deck_pitch, 2));
  difference(){
    scale([0.35, 0.35, 1]){
      linear_extrude(height = deck_flange_height){
        oshw();}}
    for(ii = [-1, 1]){
      translate([deck_pitch_diagonal / 2 * ii, 0, -.1])
        cylinder(h = deck_flange_height * 1.1,
                 r = deck_flange_screw_radius);}
    translate([0, deck_pitch_diagonal / 2, -.1])
      cylinder(h = deck_flange_height * 1.1,
               r = deck_flange_screw_radius);}}

module deck_flange_reinforcement(){
  translate([-deck_flange_radius,
             -.5 * deck_flange_height / 2,
             deck_flange_height]){
    difference (){
      cube([deck_flange_radius, deck_flange_height / 2, deck_flange_radius]);
      translate([-.1, -.05 * deck_flange_height, 0]){
        rotate([0, -45, 0]){
          cube([deck_flange_radius * 1.5, // 1.5 is bigger than sqrt(2)
                deck_flange_height * 1.1, // 1.1 is bigger than 1
                deck_flange_radius]);}}}}}

module ball_holder(){
  difference (){
    union(){
      cylinder(r = holder_radius, h = holder_height);
      translate([0, 0, holder_arms_length]){
        cylinder(r1 = holder_radius,
                 r2 = holder_radius + wall_thickness,
                 h = wall_thickness);
        translate([0, 0, wall_thickness]){
          cylinder(r = wall_thickness + holder_radius,
                   h = holder_height
                       - holder_arms_length
                       - wall_thickness); }}}
    translate([0, 0, ball_radius + holder_floor + holder_arms_length]){
      sphere(r = ball_radius);}
    translate([0, 0, holder_floor + (holder_height - holder_floor) / 2 + 0.5]){
      cube([holder_diameter + wall_thickness * 2 + 0.1,
            gap,
            holder_height - holder_floor + 0.1],
           center = true);}}}

module caster_standoff(){
  cylinder(h = standoff_lower_portion_height,
           r = standoff_radius);
  deck_flange();
  for(ii = [0:3]){
    rotate([0, 0, 45 + 90 * ii])
      deck_flange_reinforcement();}
  translate([0, 0, standoff_lower_portion_height]){
    ball_holder();}}

caster_standoff();
